Plot HOBO Logger Data
plot_hobos.RdCreates time series plots of absolute pressure and temperature from one or more HOBO logger datasets. If multiple datasets are provided, they are overlaid and colored by dataset name.
Examples
if (FALSE) { # \dontrun{
combined <- combine_hobos(Ischua_2, Ischua_3)
plot_hobos(combined)
} # }