Summarize stable TROLL observations
TROLL_stable_summary.RdSummarizes sensor values using only observations flagged as stable (i.e., where corresponding `<sensor>_stable` columns are `TRUE`).
Arguments
- df
A data frame containing sensor observations and corresponding `_stable` flag columns.
- group_col
Column used to group observations (e.g., `stationary_depth`).
- summary_fn
Summary function applied to stable values. Default is `median`.
- digits
Numeric. Number of decimal places to round result of `summary_fn`.